@@ -6,6 +6,7 @@ from unittest import TestCase
 
 import pytest
 from django.contrib.contenttypes.models import ContentType
+from django.utils import timezone
 from mock import MagicMock
 
 from multiseek.logic import (
@@ -14,7 +15,10 @@ from multiseek.logic import (
     DIFFERENT,
     EQUAL,
     EQUALITY_OPS_ALL,
+    GREATER,
     GREATER_OR_EQUAL,
+    IN_RANGE,
+    LESSER,
     LESSER_OR_EQUAL,
     MULTISEEK_ORDERING_PREFIX,
     NOT_CONTAINS,
@@ -23,8 +27,10 @@ from multiseek.logic import (
     RANGE,
     RANGE_OPS,
     STRING,
+    STRING_OPS,
     AbstractNumberQueryObject,
     AutocompleteQueryObject,
+    DateQueryObject,
     DecimalQueryObject,
     IntegerQueryObject,
     MultiseekRegistry,
@@ -58,6 +64,21 @@ test_json = json.dumps(
 
 test_buggy_json = json.dumps({"form_data": [None]})
 
+# JSON that's impossible to parse ('text field contains NULL' instead of 'equals NULL')
+test_impossible_json = json.dumps(
+    {
+        "form_data": [
+            None,
+            dict(
+                field="foo",
+                operator=text(STRING_OPS[0]),  # "CONTAINS"
+                value=None,
+                prev_op=None,
+            ),
+        ]
+    }
+)
+
 
 def py3k_test_string(s):
     return s.replace("u'", "'").replace('u"', '"').replace(", u'", ", '")
@@ -263,14 +284,21 @@ class TestMultiseekRegistry(TestCase):
             ),
         ]
 
-        self.assertRaises(UnknownOperation, self.registry.get_query_recursive, input)
+        self.registry.get_query(input)
+        self.assertEquals(len(self.registry.errors), 1)
 
         input[2]["prev_op"] = OR
 
-        res = self.registry.get_query_recursive(input)
+        res = self.registry.get_query(input)
         self.assertEqual(
             str(res), py3k_test_string("(OR: (u'foo', u'foo'), (u'foo', u'bar'))")
         )
+        self.assertEquals(len(self.registry.errors), 0)
+
+    def test_get_query_errors(self):
+        self.registry.get_query(json.loads(test_impossible_json)["form_data"])
+        self.assertEqual(len(self.registry.errors), 1)
+        self.assertEqual(self.registry.errors[0][1]["field"], "foo")
 
     def test_get_query(self):
         gq = self.registry.get_query(json.loads(test_json)["form_data"])
@@ -372,3 +400,17 @@ def test_impacts_query_StringQueryObject():
     assert a.impacts_query(None, DIFFERENT)
     assert not a.impacts_query(None, CONTAINS)
     assert not a.impacts_query(None, NOT_CONTAINS)
+
+
+@pytest.mark.parametrize(
+    "operation",
+    [IN_RANGE, EQUAL, DIFFERENT, GREATER_OR_EQUAL, GREATER, LESSER_OR_EQUAL, LESSER],
+)
+def test_DateQuery_operation(operation):
+    """Test that DateQuery.real_query gives a correct Query for
+    each of operator type"""
+
+    value = timezone.now()
+    if operation == IN_RANGE:
+        value = [value, value]
+    assert DateQueryObject("foo").real_query(value, operation) is not None
